Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(495)

Unified Diff: pkg/analyzer/lib/task/dart.dart

Issue 1124923002: Compute explicit imports (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/analyzer/lib/src/task/dart.dart ('k') | pkg/analyzer/test/src/task/dart_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analyzer/lib/task/dart.dart
diff --git a/pkg/analyzer/lib/task/dart.dart b/pkg/analyzer/lib/task/dart.dart
index a4ac9ee1bc7b351dab11cc07dc3ea8ed4094eeb7..2c79bb3daaa887e80ad629de805506347368e125 100644
--- a/pkg/analyzer/lib/task/dart.dart
+++ b/pkg/analyzer/lib/task/dart.dart
@@ -24,6 +24,17 @@ final CompositeResultDescriptor<List<AnalysisError>> DART_ERRORS =
new CompositeResultDescriptor<List<AnalysisError>>('DART_ERRORS');
/**
+ * The sources of the libraries that are explicitly imported into a library.
+ *
+ * The list will be empty if there are no explicit imports, but will not be
+ * `null`.
+ *
+ * The result is only available for targets representing a Dart library.
+ */
+final ListResultDescriptor<Source> EXPLICITLY_IMPORTED_LIBRARIES =
+ new ListResultDescriptor<Source>('EXPLICITLY_IMPORTED_LIBRARIES', Source.EMPTY_ARRAY);
+
+/**
* The sources of the libraries that are exported from a library.
*
* The list will be empty if there are no exported libraries, but will not be
@@ -35,11 +46,11 @@ final ListResultDescriptor<Source> EXPORTED_LIBRARIES =
new ListResultDescriptor<Source>('EXPORTED_LIBRARIES', Source.EMPTY_ARRAY);
/**
* The sources of the libraries that are imported into a library.
*
- * Not `null`.
- * The default value is empty.
- * When computed, this list will always contain at least `dart:core` source.
+ * The list will minimally contain the source for `dart:core` because it is
+ * implicitly imported into every library, and therefore will never be `null`.
*
* The result is only available for targets representing a Dart library.
*/
@@ -35,11 +46,11 @@ final ListResultDescriptor<Source> EXPORTED_LIBRARIES =
new ListResultDescriptor<Source>('EXPORTED_LIBRARIES', Source.EMPTY_ARRAY);
/**
- * The sources of the libraries that are imported into a library.
+ * The sources of the libraries that are implicitly or explicitly imported into
+ * a library.
*
« no previous file with comments | « pkg/analyzer/lib/src/task/dart.dart ('k') | pkg/analyzer/test/src/task/dart_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698